@@ -30,5 +30,5 @@ class Component() :
         pass
 
 
-    def onCollide(self):
+    def onCollide(self,obj):
         pass
\ No newline at end of file
